==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'só aos artigos futuros (non modificar nin facer nada na base de datos).',
	'bouton_radio_articles_tous' => 'a todos os artigos sen excepción.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todos os artigos, agás ós que teñan o foro desactivado;.',
	'bouton_radio_enregistrement_obligatoire' => 'Rexistro obrigatorio (se quere usar este servizo ten que se rexistrar co seu enderezo de correo-e. antes de poder achegar contribucións).',
	'bouton_radio_moderation_priori' => 'Moderado a priori (as
  contribucións serán publicadas trala aprobación do grupo xestor).', # MODIF
	'bouton_radio_modere_abonnement' => 'con subscrición',
	'bouton_radio_modere_posteriori' => 'moderación a posteriori',
	'bouton_radio_modere_priori' => 'moderación a priori',
	'bouton_radio_publication_immediate' => 'Publicación inmediata das mensaxes
		(as contribucións amósanse dende o seu envío, o equipo de xestión pódeas borrar).',

	// D
	'documents_interdits_forum' => 'Os documentos están prohibidos no foro',

	// F
	'form_pet_message_commentaire' => 'Algunha mensaxe, un comentario?',
	'forum' => 'Foro',
	'forum_acces_refuse' => 'Non tes acceso a estes foros.',
	'forum_attention_dix_caracteres' => '<b>Atención!</b> a súa mensaxe debe conter máis de dez caracteres.',
	'forum_attention_trois_caracteres' => '<b>Atención!</b> o seu título debe ter máis de tres caracteres.',
	'forum_attention_trop_caracteres' => '<b>Atencion !</b> a mensaxe é demasiado longa (@compte@ caracteres) : para poder ser rexistrada, non debe sobrepasar  @max@ caracteres.', # MODIF
	'forum_avez_selectionne' => 'Seleccionou :',
	'forum_cliquer_retour' => 'Preme <a href=\'@retour_forum@\'>aquí</a> para seguir.',
	'forum_forum' => 'foro',
	'forum_info_modere' => 'Este foro é moderado a priori : a súa contribución non aparecerá namentres non sexa aprobada por un administrador do web.', # MODIF
	'forum_lien_hyper' => 'Ligazón de hipertexto',
	'forum_message_definitif' => 'Mensaxe definitiva: enviala ao web',
	'forum_message_trop_long' => 'A mensaxe é longa de máis. O tamaño máximo permitido é de 20000 caractéres.', # MODIF
	'forum_ne_repondez_pas' => 'Non responda a este correo senón no foro do enderezo seguinte:',
	'forum_page_url' => '(Se a súa mensaxe se refire a un artigo publicado en Internet, ou a unha páxina que contén máis informacións, indique a continuación o título da páxina e o seu enderezo URL)',
	'forum_poste_par' => 'Mensaxe de @parauteur@ relacionada co artigo « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => 'Quen é vostede?',
	'forum_texte' => 'Texto da súa mensaxe',
	'forum_titre' => 'Título',
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar a elección',
	'forum_voir_avant' => 'Ver a mensaxe antes de enviala', # MODIF
	'forum_votre_email' => 'O teu enderezo de correo-e.:', # MODIF
	'forum_votre_nom' => 'O teu nome (ou alcume):', # MODIF
	'forum_vous_enregistrer' => 'Para participar neste foro, ten que se rexistrar
  con anterioridade. Escriba aquí embaixo o identificador persoal
  que recibiu. Se aínda non se rexistrou, débeo facer',
	'forum_vous_inscrire' => 'inscribirse.',

	// I
	'icone_poster_message' => 'Enviar unha mensaxe',
	'icone_suivi_forum' => 'Seguimento do foro público: @nb_forums@ contribución(s)',
	'icone_suivi_forums' => 'Seguir/xestionar os foros',
	'icone_supprimer_message' => 'Borrar esta mensaxe',
	'icone_valider_message' => 'Validar a mensaxe',
	'info_activer_forum_public' => '<i>Para activar os foros públicos, escolla o xeito
  de moderación predeterminado:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar esta opción de moderación:',
	'info_config_forums_prive' => 'No espazo privado do web, pode activar varios tipos de foros :', # MODIF
	'info_config_forums_prive_admin' => 'Un foro reservado aos administradores do web :',
	'info_config_forums_prive_global' => 'Un foro global, aberto a todos os redactores :',
	'info_config_forums_prive_objets' => 'Un foro sobre cada artigo, breve, web referido, etc. :',
	'info_desactiver_forum_public' => 'Desactivar o uso dos foros
  públicos. Os foros públicos poderán ser autorizados caso por caso
  nos artigos; serán prohibidos nos temas, nas breves, etc.',
	'info_envoi_forum' => 'Envío de foros ás/ós autoras/es dos artigos',
	'info_fonctionnement_forum' => 'Funcionamento do foro:',
	'info_gauche_suivi_forum_2' => 'A p´xina de <i>seguimento dos foros</i>  &eeacute; unha ferramenta de xestión do web (e non un espazo de discusión ou de redacción). Mostra todas as contribucións nos foros do web, tanto as do espazo público coma as do espazo privado e permite xestionar estas contribucións.', # MODIF
	'info_liens_syndiques_3' => 'foros',
	'info_liens_syndiques_4' => 'están',
	'info_liens_syndiques_5' => 'foro',
	'info_liens_syndiques_6' => 'está',
	'info_liens_syndiques_7' => 'agardando pola validación',
	'info_mode_fonctionnement_defaut_forum_public' => 'Configuración por defecto dos foros públicos',
	'info_option_email' => 'Cando unha visita envía unha nova mensaxe no foro
  vencellado a un artigo, os autores relacionados co artigo poden recibir
  aviso desta mensaxe por correo-e. Quere preguntar para cada tipo de foro se cómpre empregar esta opción?',
	'info_pas_de_forum' => 'non hai foro',
	'info_question_visiteur_ajout_document_forum' => 'Se quere autorizar os visitantes para que poidan anexar documentos (imaxes, sons...) nas súas mensaxes dos foros, indique a seguir a lista de extensións autorizadas para os foros (ex: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Se quere autorizar todos os tipos de documentos considerados como fiables por SPIP, marque unha estrela. Para non autorizar nada, non indique nada.', # MODIF
	'item_activer_forum_administrateur' => 'Activar o foro do equipo de xestión',
	'item_config_forums_prive_global' => 'Activar o foro dos redactores',
	'item_config_forums_prive_objets' => 'Activar estes foros',
	'item_desactiver_forum_administrateur' => 'Desactivar o foro do equipo de xestión',
	'item_non_config_forums_prive_global' => 'Desactivar o foro dos redactores',
	'item_non_config_forums_prive_objets' => 'Desactivar estes foros',

	// L
	'lien_reponse_article' => 'Responder ao artigo',
	'lien_reponse_breve_2' => 'Resposta á breve',
	'lien_reponse_rubrique' => 'Resposta ó tema',
	'lien_reponse_site_reference' => 'Resposta ao web referido:', # MODIF

	// O
	'onglet_messages_internes' => 'Mensaxes internas',
	'onglet_messages_publics' => 'Mensaxes públicas',
	'onglet_messages_vide' => 'Mensaxes sen texto',

	// R
	'repondre_message' => 'Responder a esta mensaxe',

	// S
	'statut_original' => 'orixinal',

	// T
	'text_article_propose_publication_forum' => 'Non dubide avisar a través do foro asociado a este artigo (a pé de páxina).',
	'texte_en_cours_validation_forum' => 'Non dubide avisar a través dos foros que levan engadidos.',
	'titre_cadre_forum_administrateur' => 'Foro privado de xestión',
	'titre_cadre_forum_interne' => 'Foro interno',
	'titre_config_forums_prive' => 'Foros do espazo privado',
	'titre_forum' => 'Foro',
	'titre_forum_suivi' => 'Seguimento dos foros',
	'titre_page_forum_suivi' => 'Seguimento dos foros'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=gl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'só aos artigos futuros (non modificar nin facer nada na base de datos).',
	'bouton_radio_articles_tous' => 'a todos os artigos sen excepción.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todos os artigos, agás ós que teñan o foro desactivado;.',
	'bouton_radio_enregistrement_obligatoire' => 'Rexistro obrigatorio (se quere usar este servizo ten que se rexistrar co seu enderezo de correo-e. antes de poder achegar contribucións).',
	'bouton_radio_moderation_priori' => 'Moderado a priori (as
  contribucións serán publicadas trala aprobación do grupo xestor).', # MODIF
	'bouton_radio_modere_abonnement' => 'con subscrición',
	'bouton_radio_modere_posteriori' => 'moderación a posteriori',
	'bouton_radio_modere_priori' => 'moderación a priori',
	'bouton_radio_publication_immediate' => 'Publicación inmediata das mensaxes
		(as contribucións amósanse dende o seu envío, o equipo de xestión pódeas borrar).',

	// D
	'documents_interdits_forum' => 'Os documentos están prohibidos no foro',

	// F
	'form_pet_message_commentaire' => 'Algunha mensaxe, un comentario?',
	'forum' => 'Foro',
	'forum_acces_refuse' => 'Non tes acceso a estes foros.',
	'forum_attention_dix_caracteres' => '<b>Atención!</b> a súa mensaxe debe conter máis de dez caracteres.',
	'forum_attention_trois_caracteres' => '<b>Atención!</b> o seu título debe ter máis de tres caracteres.',
	'forum_attention_trop_caracteres' => '<b>Atencion !</b> a mensaxe é demasiado longa (@compte@ caracteres) : para poder ser rexistrada, non debe sobrepasar  @max@ caracteres.', # MODIF
	'forum_avez_selectionne' => 'Seleccionou :',
	'forum_cliquer_retour' => 'Preme <a href=\'@retour_forum@\'>aquí</a> para seguir.',
	'forum_forum' => 'foro',
	'forum_info_modere' => 'Este foro é moderado a priori : a súa contribución non aparecerá namentres non sexa aprobada por un administrador do web.', # MODIF
	'forum_lien_hyper' => 'Ligazón de hipertexto',
	'forum_message_definitif' => 'Mensaxe definitiva: enviala ao web',
	'forum_message_trop_long' => 'A mensaxe é longa de máis. O tamaño máximo permitido é de 20000 caractéres.', # MODIF
	'forum_ne_repondez_pas' => 'Non responda a este correo senón no foro do enderezo seguinte:',
	'forum_page_url' => '(Se a súa mensaxe se refire a un artigo publicado en Internet, ou a unha páxina que contén máis informacións, indique a continuación o título da páxina e o seu enderezo URL)',
	'forum_poste_par' => 'Mensaxe de @parauteur@ relacionada co artigo « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => 'Quen é vostede?',
	'forum_texte' => 'Texto da súa mensaxe',
	'forum_titre' => 'Título',
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar a elección',
	'forum_voir_avant' => 'Ver a mensaxe antes de enviala', # MODIF
	'forum_votre_email' => 'O teu enderezo de correo-e.:', # MODIF
	'forum_votre_nom' => 'O teu nome (ou alcume):', # MODIF
	'forum_vous_enregistrer' => 'Para participar neste foro, ten que se rexistrar
  con anterioridade. Escriba aquí embaixo o identificador persoal
  que recibiu. Se aínda non se rexistrou, débeo facer',
	'forum_vous_inscrire' => 'inscribirse.',

	// I
	'icone_poster_message' => 'Enviar unha mensaxe',
	'icone_suivi_forum' => 'Seguimento do foro público: @nb_forums@ contribución(s)',
	'icone_suivi_forums' => 'Seguir/xestionar os foros',
	'icone_supprimer_message' => 'Borrar esta mensaxe',
	'icone_valider_message' => 'Validar a mensaxe',
	'info_activer_forum_public' => '<i>Para activar os foros públicos, escolla o xeito
  de moderación predeterminado:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar esta opción de moderación:',
	'info_config_forums_prive' => 'No espazo privado do web, pode activar varios tipos de foros :', # MODIF
	'info_config_forums_prive_admin' => 'Un foro reservado aos administradores do web :',
	'info_config_forums_prive_global' => 'Un foro global, aberto a todos os redactores :',
	'info_config_forums_prive_objets' => 'Un foro sobre cada artigo, breve, web referido, etc. :',
	'info_desactiver_forum_public' => 'Desactivar o uso dos foros
  públicos. Os foros públicos poderán ser autorizados caso por caso
  nos artigos; serán prohibidos nos temas, nas breves, etc.',
	'info_envoi_forum' => 'Envío de foros ás/ós autoras/es dos artigos',
	'info_fonctionnement_forum' => 'Funcionamento do foro:',
	'info_gauche_suivi_forum_2' => 'A p´xina de <i>seguimento dos foros</i>  &eeacute; unha ferramenta de xestión do web (e non un espazo de discusión ou de redacción). Mostra todas as contribucións nos foros do web, tanto as do espazo público coma as do espazo privado e permite xestionar estas contribucións.', # MODIF
	'info_liens_syndiques_3' => 'foros',
	'info_liens_syndiques_4' => 'están',
	'info_liens_syndiques_5' => 'foro',
	'info_liens_syndiques_6' => 'está',
	'info_liens_syndiques_7' => 'agardando pola validación',
	'info_mode_fonctionnement_defaut_forum_public' => 'Configuración por defecto dos foros públicos',
	'info_option_email' => 'Cando unha visita envía unha nova mensaxe no foro
  vencellado a un artigo, os autores relacionados co artigo poden recibir
  aviso desta mensaxe por correo-e. Quere preguntar para cada tipo de foro se cómpre empregar esta opción?',
	'info_pas_de_forum' => 'non hai foro',
	'info_question_visiteur_ajout_document_forum' => 'Se quere autorizar os visitantes para que poidan anexar documentos (imaxes, sons...) nas súas mensaxes dos foros, indique a seguir a lista de extensións autorizadas para os foros (ex: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Se quere autorizar todos os tipos de documentos considerados como fiables por SPIP, marque unha estrela. Para non autorizar nada, non indique nada.', # MODIF
	'item_activer_forum_administrateur' => 'Activar o foro do equipo de xestión',
	'item_config_forums_prive_global' => 'Activar o foro dos redactores',
	'item_config_forums_prive_objets' => 'Activar estes foros',
	'item_desactiver_forum_administrateur' => 'Desactivar o foro do equipo de xestión',
	'item_non_config_forums_prive_global' => 'Desactivar o foro dos redactores',
	'item_non_config_forums_prive_objets' => 'Desactivar estes foros',

	// L
	'lien_reponse_article' => 'Responder ao artigo',
	'lien_reponse_breve_2' => 'Resposta á breve',
	'lien_reponse_rubrique' => 'Resposta ó tema',
	'lien_reponse_site_reference' => 'Resposta ao web referido:', # MODIF

	// O
	'onglet_messages_internes' => 'Mensaxes internas',
	'onglet_messages_publics' => 'Mensaxes públicas',
	'onglet_messages_vide' => 'Mensaxes sen texto',

	// R
	'repondre_message' => 'Responder a esta mensaxe',

	// S
	'statut_original' => 'orixinal',

	// T
	'text_article_propose_publication_forum' => 'Non dubide avisar a través do foro asociado a este artigo (a pé de páxina).',
	'texte_en_cours_validation_forum' => 'Non dubide avisar a través dos foros que levan engadidos.',
	'titre_cadre_forum_administrateur' => 'Foro privado de xestión',
	'titre_cadre_forum_interne' => 'Foro interno',
	'titre_config_forums_prive' => 'Foros do espazo privado',
	'titre_forum' => 'Foro',
	'titre_forum_suivi' => 'Seguimento dos foros',
	'titre_page_forum_suivi' => 'Seguimento dos foros',
];
